@@ -2,13 +2,13 @@ from __future__ import annotations
 from typing import Any, Optional, TypeVar, cast, TYPE_CHECKING
 from datetime import date
 from jsonclasses.types import Types
-from jsonclasses.fdef import FieldStorage, FieldType
-from jsonclasses.mark_graph import MarkGraph
+from jsonclasses.fdef import FStore, FType
+from jsonclasses.mgraph import MGraph
 from inflection import underscore, camelize
 from .utils import (ref_field_key, ref_field_keys, ref_db_field_key,
                     ref_db_field_keys)
 from .coder import Coder
-from .dbconf import DBConf
+from .pconf import PConf
 if TYPE_CHECKING:
     from .pymongo_object import PymongoObject
     T = TypeVar('T', bound=PymongoObject)
@@ -20,7 +20,7 @@ class Decoder(Coder):
                     value: list[Any],
                     cls: type[T],
                     types: Types,
-                    graph: MarkGraph) -> Optional[list[Any]]:
+                    graph: MGraph) -> Optional[list[Any]]:
         if value is None:
             return None
         item_types = types.fdef.item_types
@@ -34,28 +34,18 @@ class Decoder(Coder):
                     value: dict[str, Any],
                     cls: type[T],
                     types: Types,
-                    graph: MarkGraph) -> Optional[dict[str, Any]]:
+                    graph: MGraph) -> Optional[dict[str, Any]]:
         if value is None:
             return None
-        config: DBConf = cls.dbconf
-        if types.fdef.field_storage == FieldStorage.FOREIGN_KEY:
-            return None
-        if types.fdef.field_storage == FieldStorage.LOCAL_KEY:
-            return ({underscore(k) if config.camelize_db_keys else k: str(v)
-                    for k, v in value.items()})
-        else:
-            item_types = types.fdef.item_types
-            return ({underscore(k) if config.camelize_db_keys else k:
-                    self.decode_item(value=v, cls=cls, types=item_types,
-                                     graph=graph)
-                    for k, v in value.items()})
+        item_types = types.fdef.item_types
+        return {k: self.decode_item(value=v, cls=cls, types=item_types, graph=graph) for k, v in value.items()}
 
     def decode_shape(self,
                      value: dict[str, Any],
                      cls: type[T],
                      types: Types,
-                     graph: MarkGraph) -> dict[str, Any]:
-        config: DBConf = cls.dbconf
+                     graph: MGraph) -> dict[str, Any]:
+        config: PConf = cls.pconf
         shape_types = cast(dict[str, Any], types.fdef.raw_shape_types)
         retval = {}
         for k, item_types in shape_types.items():
@@ -71,28 +61,28 @@ class Decoder(Coder):
                     value: Any,
                     cls: type[T],
                     types: Types,
-                    graph: MarkGraph) -> Any:
+                    graph: MGraph) -> Any:
         if value is None:
             return value
-        if types.fdef.field_type == FieldType.DATE:
+        if types.fdef.ftype == FType.DATE:
             return date.fromisoformat(value.isoformat()[:10])
-        elif types.fdef.field_type == FieldType.ENUM:
+        elif types.fdef.ftype == FType.ENUM:
             if isinstance(types.fdef.enum_class, str):
                 enum_cls = cast(type, types.fdef.enum_class)
                 return enum_cls(value)
             else:
                 enum_cls = cast(type, types.fdef.enum_class)
                 return enum_cls(value)
-        elif types.fdef.field_type == FieldType.LIST:
+        elif types.fdef.ftype == FType.LIST:
             return self.decode_list(value=value, cls=cls, types=types,
                                     graph=graph)
-        elif types.fdef.field_type == FieldType.DICT:
+        elif types.fdef.ftype == FType.DICT:
             return self.decode_dict(value=value, cls=cls, types=types,
                                     graph=graph)
-        elif types.fdef.field_type == FieldType.SHAPE:
+        elif types.fdef.ftype == FType.SHAPE:
             return self.decode_shape(value=value, cls=cls, types=types,
                                      graph=graph)
-        elif types.fdef.field_type == FieldType.INSTANCE:
+        elif types.fdef.ftype == FType.INSTANCE:
             return self.decode_instance(value=value, cls=cls, types=types,
                                         graph=graph)
         else:
@@ -102,7 +92,7 @@ class Decoder(Coder):
                         value: dict[str, Any],
                         cls: type[T],
                         types: Types,
-                        graph: MarkGraph) -> Any:
+                        graph: MGraph) -> Any:
         inst_id = str(value.get('_id'))
         dest = graph.getp(cls, inst_id)
         exist = True
@@ -110,7 +100,7 @@ class Decoder(Coder):
             dest = cls()
             exist = False
         for field in cls.cdef.fields:
-            if cls.dbconf.camelize_db_keys:
+            if cls.pconf.camelize_db_keys:
                 key = camelize(field.name, False)
             else:
                 key = field.name
@@ -167,9 +157,9 @@ class Decoder(Coder):
         return dest
 
     def apply_initial_status(self, root: T,
-                             graph: Optional[MarkGraph] = None) -> None:
+                             graph: Optional[MGraph] = None) -> None:
         if graph is None:
-            graph = MarkGraph()
+            graph = MGraph()
         if graph.get(root) is not None:
             return
         graph.put(root)
@@ -186,9 +176,9 @@ class Decoder(Coder):
     def decode_root(self,
                     root: dict[str, Any],
                     cls: type[T],
-                    graph: Optional[MarkGraph] = None) -> T:
+                    graph: Optional[MGraph] = None) -> T:
         if graph is None:
-            graph = MarkGraph()
+            graph = MGraph()
         types = Types().instanceof(cls)
         decoded = self.decode_instance(root, cls, types, graph)
         self.apply_initial_status(decoded)
@@ -197,9 +187,9 @@ class Decoder(Coder):
     def decode_root_list(self,
                          root_list: list[dict[str, Any]],
                          cls: type[T],
-                         graph: Optional[MarkGraph] = None) -> list[T]:
+                         graph: Optional[MGraph] = None) -> list[T]:
         if graph is None:
-            graph = MarkGraph()
+            graph = MGraph()
         types = Types().instanceof(cls)
         results: list[T] = []
         for root in root_list:
