@@ -4,9 +4,9 @@ from datetime import datetime
 from inflection import camelize
 from bson.objectid import ObjectId
 from jsonclasses.jfield import JField
-from jsonclasses.fdef import FieldStorage, FieldType
+from jsonclasses.fdef import FStore, FType
 from jsonclasses.keypath import concat_keypath
-from jsonclasses.mark_graph import MarkGraph
+from jsonclasses.mgraph import MGraph
 from jsonclasses.types import types
 from .coder import Coder
 from .utils import ref_db_field_key, ref_db_field_keys, ref_field_key
@@ -35,9 +35,9 @@ class Encoder(Coder):
         value = cast(list[Any], context.value)
         fd = context.types.fdef
         item_types = fd.item_types
-        if fd.field_storage == FieldStorage.FOREIGN_KEY:
+        if fd.fstore == FStore.FOREIGN_KEY:
             item_types = item_types.linkedby(cast(str, fd.foreign_key))
-        if fd.field_storage == FieldStorage.LOCAL_KEY:
+        if fd.fstore == FStore.LOCAL_KEY:
             item_types = item_types.linkto
         result = []
         commands = []
@@ -57,9 +57,7 @@ class Encoder(Coder):
         if context.value is None:
             return EncodingResult(result=None, commands=[])
         value = cast(dict[str, Any], context.value)
-        fd = context.types.fdef
-        item_types = fd.item_types
-        camelized = context.owner.__class__.dbconf.camelize_db_keys
+        item_types = context.types.fdef.item_types
         result = {}
         commands = []
         for key, item in value.items():
@@ -70,7 +68,7 @@ class Encoder(Coder):
                 keypath_owner=concat_keypath(context.keypath_owner, key),
                 keypath_parent=str(key),
                 parent=value))
-            result[camelize(key, False) if camelized else key] = item_result
+            result[key] = item_result
             commands.extend(item_commands)
         return EncodingResult(result, commands)
 
@@ -80,7 +78,7 @@ class Encoder(Coder):
         value = cast(dict[str, Any], context.value)
         fd = context.types.fdef
         shape_types = cast(dict[str, Any], fd.shape_types)
-        camelized = context.owner.__class__.dbconf.camelize_db_keys
+        camelized = context.owner.__class__.pconf.camelize_db_keys
         result = {}
         commands = []
         for key, item in value.items():
@@ -159,7 +157,7 @@ class Encoder(Coder):
             return EncodingResult({'_id': ObjectId(id)}, commands=[])
         context.mark_graph.put(value)
         instance_fd = context.types.fdef
-        write_instance = instance_fd.field_storage != FieldStorage.EMBEDDED
+        write_instance = instance_fd.fstore != FStore.EMBEDDED
         if root:
             write_instance = True
         use_insert_command = False
@@ -211,7 +209,7 @@ class Encoder(Coder):
                         join_command = self._join_command(
                             value,
                             field,
-                            self.list_instance_type(field, cls),
+                            self.list_instance_type(field),
                             list_item['_id'])
                         commands.append(join_command)
                 for item in value.unlinked_objects[field.name]:
@@ -219,12 +217,12 @@ class Encoder(Coder):
                         unlink_command = self._unlink_command(
                             value,
                             field,
-                            self.list_instance_type(field, cls),
+                            self.list_instance_type(field),
                             ObjectId(item._id))
                         commands.append(unlink_command)
             elif self.is_local_key_reference_field(field):
                 if fvalue is None:
-                    tsfm = value.__class__.cdef.jconf.key_transformer
+                    tsfm = value.__class__.cdef.jconf.ref_key_encoding_strategy
                     if getattr(value, tsfm(field)) is not None:
                         if use_insert_command or fname in fields_need_update:
                             result_set[ref_db_field_key(fname, cls)] = \
@@ -278,7 +276,7 @@ class Encoder(Coder):
                     keypath_parent=fname,
                     parent=value))
                 if use_insert_command or fname in fields_need_update:
-                    if context.owner.__class__.dbconf.camelize_db_keys:
+                    if context.owner.__class__.pconf.camelize_db_keys:
                         result_set[camelize(field.name, False)] = item_result
                     else:
                         result_set[field.name] = item_result
@@ -307,20 +305,20 @@ class Encoder(Coder):
     def encode_item(self, context: EncodingContext) -> EncodingResult:
         if context.value is None:
             return EncodingResult(result=None, commands=[])
-        field_type = context.types.fdef.field_type
-        if field_type == FieldType.LIST:
+        ftype = context.types.fdef.ftype
+        if ftype == FType.LIST:
             return self.encode_list(context)
-        elif field_type == FieldType.DICT:
+        elif ftype == FType.DICT:
             return self.encode_dict(context)
-        elif field_type == FieldType.SHAPE:
+        elif ftype == FType.SHAPE:
             return self.encode_shape(context)
-        elif field_type == FieldType.INSTANCE:
+        elif ftype == FType.INSTANCE:
             return self.encode_instance(context)
-        elif field_type == FieldType.DATE:
+        elif ftype == FType.DATE:
             return EncodingResult(
                 result=datetime.fromisoformat(context.value.isoformat()),
                 commands=[])
-        elif field_type == FieldType.ENUM:
+        elif ftype == FType.ENUM:
             return EncodingResult(result=context.value.value, commands=[])
         else:
             return EncodingResult(context.value, [])
@@ -335,5 +333,5 @@ class Encoder(Coder):
             owner=root,
             keypath_parent='',
             parent=root,
-            mark_graph=MarkGraph()), root=True)[1]
+            mark_graph=MGraph()), root=True)[1]
         return BatchCommand(commands=commands)
