@@ -6,7 +6,7 @@ from typing import TypeVar, ClassVar, Any, Union, TYPE_CHECKING
 from bson.objectid import ObjectId
 from jsonclasses.jobject import JObject
 if TYPE_CHECKING:
-    from .dbconf import DBConf
+    from .pconf import PConf
     from .query import (BaseQuery, ListQuery, IDQuery, SingleQuery, ExistQuery,
                         IterateQuery)
 
@@ -19,17 +19,17 @@ class PymongoObject(JObject):
     jsonclass object should confirm to.
     """
 
-    dbconf: ClassVar[DBConf]
+    pconf: ClassVar[PConf]
     """The configuration user passed to JSON class through the jsonclass
     decorator.
     """
 
     @classmethod
-    def find(cls: type[T], **kwargs: Any) -> ListQuery[T]:
+    def find(cls: type[T], *args, **kwargs: Any) -> ListQuery[T]:
         ...
 
     @classmethod
-    def one(cls: type[T], **kwargs: Any) -> SingleQuery[T]:
+    def one(cls: type[T], *args, **kwargs: Any) -> SingleQuery[T]:
         ...
 
     @classmethod
