@@ -6,9 +6,9 @@ from jsonclasses.jfield import JField
 from pymongo.errors import DuplicateKeyError
 from inflection import camelize, underscore
 from pymongo.collection import Collection
-from jsonclasses.fdef import FieldStorage, FieldType
-from jsonclasses.exceptions import UniqueConstraintException
-from jsonclasses.exceptions import DeletionDeniedException
+from jsonclasses.fdef import FStore, FType
+from jsonclasses.excs import UniqueConstraintException
+from jsonclasses.excs import DeletionDeniedException
 from .pymongo_object import PymongoObject
 from .query import BaseQuery, ExistQuery, IterateQuery, ListQuery, SingleQuery, IDQuery
 from .encoder import Encoder
@@ -20,12 +20,18 @@ from .coder import Coder
 T = TypeVar('T', bound=PymongoObject)
 
 
-def find(cls: type[T], **kwargs: Any) -> ListQuery[T]:
-    return ListQuery(cls=cls, filter=kwargs)
+def find(cls: type[T], *args, **kwargs: Any) -> ListQuery[T]:
+    if len(args) > 0:
+        return ListQuery(cls=cls, filter=args[0])
+    else:
+        return ListQuery(cls=cls, filter=kwargs)
 
 
-def one(cls: type[T], **kwargs: Any) -> SingleQuery[T]:
-    return SingleQuery(cls=cls, filter=kwargs)
+def one(cls: type[T], *args, **kwargs: Any) -> SingleQuery[T]:
+    if len(args) > 0:
+        return SingleQuery(cls=cls, filter=args[0])
+    else:
+        return SingleQuery(cls=cls, filter=kwargs)
 
 
 def pymongo_id(cls: type[T], id: Union[str, ObjectId]) -> IDQuery[T]:
@@ -52,28 +58,23 @@ def _database_write(self: T) -> None:
         assert result is not None
         db_key = result.group(1)
         pt_key = db_key
-        json_key = db_key
-        if self.__class__.dbconf.camelize_db_keys:
+        if self.__class__.pconf.camelize_db_keys:
             pt_key = underscore(db_key)
-            json_key = pt_key
-        if self.__class__.cdef.jconf.camelize_json_keys:
-            json_key = camelize(pt_key, False)
-        raise UniqueConstraintException(
-                getattr(self, pt_key), json_key) from None
+        raise UniqueConstraintException(pt_key) from None
 
 
 def _orm_delete(self: T, no_raise: bool = False) -> None:
     # deny test
     for field in self.__class__.cdef.deny_fields:
-        if field.fdef.field_storage == FieldStorage.LOCAL_KEY:
-            key = self.__class__.cdef.jconf.key_transformer(field)
+        if field.fdef.fstore == FStore.LOCAL_KEY:
+            key = self.__class__.cdef.jconf.ref_key_encoding_strategy(field)
             if hasattr(self, key) and getattr(self, key) is not None:
                 if no_raise:
                     return
                 else:
                     raise DeletionDeniedException()
-        elif field.fdef.field_storage == FieldStorage.FOREIGN_KEY:
-            if field.fdef.field_type == FieldType.LIST:
+        elif field.fdef.fstore == FStore.FOREIGN_KEY:
+            if field.fdef.ftype == FType.LIST:
                 oc = field.fdef.item_types.fdef.inst_cls
             else:
                 oc = field.fdef.inst_cls
@@ -94,7 +95,7 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
                     else:
                         raise DeletionDeniedException()
             else:
-                key = oc.cdef.jconf.key_transformer(f)
+                key = oc.cdef.jconf.ref_key_encoding_strategy(f)
                 exist = oc.exist(**{key: ObjectId(self._id)}).exec()
                 if exist:
                     if no_raise:
@@ -107,8 +108,8 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
 
     # delete chain - nullify
     for field in self.__class__.cdef.nullify_fields:
-        if field.fdef.field_storage == FieldStorage.FOREIGN_KEY:
-            if field.fdef.field_type == FieldType.LIST:
+        if field.fdef.fstore == FStore.FOREIGN_KEY:
+            if field.fdef.ftype == FType.LIST:
                 oc = field.fdef.item_types.fdef.inst_cls
             else:
                 oc = field.fdef.inst_cls
@@ -123,7 +124,7 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
                 key = ref_db_field_key(self.__class__.__name__, self.__class__)
                 coll.delete_many({key: ObjectId(self._id)})
             else:
-                key = oc.cdef.jconf.key_transformer(f)
+                key = oc.cdef.jconf.ref_key_encoding_strategy(f)
                 for o in oc.iterate(**{key: ObjectId(self._id)}).exec():
                     setattr(o, f.name, None)
                     setattr(o, key, None)
@@ -131,18 +132,18 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
 
     # delete chain - cascade
     for field in self.__class__.cdef.cascade_fields:
-        if field.fdef.field_type == FieldType.LIST:
+        if field.fdef.ftype == FType.LIST:
             oc = field.fdef.item_types.fdef.inst_cls
         else:
             oc = field.fdef.inst_cls
         f = cast(JField, field.foreign_field)
-        if field.fdef.field_storage == FieldStorage.LOCAL_KEY:
-            key = self.__class__.cdef.jconf.key_transformer(field)
+        if field.fdef.fstore == FStore.LOCAL_KEY:
+            key = self.__class__.cdef.jconf.ref_key_encoding_strategy(field)
             if getattr(self, key) is not None:
                 item = oc.id(getattr(self, key)).optional.exec()
                 if item is not None:
                     item._orm_delete(no_raise=True)
-        elif field.fdef.field_storage == FieldStorage.FOREIGN_KEY:
+        elif field.fdef.fstore == FStore.FOREIGN_KEY:
             if field.fdef.use_join_table:
                 jtname = Coder().join_table_name(
                     self.__class__,
@@ -159,7 +160,7 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
                         item._orm_delete(no_raise=True)
                 coll.delete_many({key: ObjectId(self._id)})
             else:
-                key = oc.cdef.jconf.key_transformer(f)
+                key = oc.cdef.jconf.ref_key_encoding_strategy(f)
                 for o in oc.iterate(**{key: ObjectId(self._id)}).exec():
                     o._orm_delete(no_raise=True)
 
@@ -194,13 +195,13 @@ def pymongofy(class_: type) -> PymongoObject:
         info = coll.index_information()
         for field in class_.cdef.fields:
             name = field.name
-            if class_.dbconf.camelize_db_keys:
+            if class_.pconf.camelize_db_keys:
                 name = camelize(field.name, False)
             index = field.fdef.index
             unique = field.fdef.unique
             required = field.fdef.required
             index_name = f'{name}_1'
-            ftype = field.fdef.field_type
+            ftype = field.fdef.ftype
             if unique:
                 if required:
                     coll.create_index(name, name=index_name, unique=True)
@@ -222,5 +223,5 @@ def pymongofy(class_: type) -> PymongoObject:
             else:
                 if index_name in info.keys():
                     coll.drop_index(index_name)
-    connection.add_connected_callback(class_.dbconf.collection_name, callback)
+    connection.add_connected_callback(class_.pconf.collection_name, callback)
     return class_
