@@ -1,13 +1,16 @@
 """This module contains queries."""
 from __future__ import annotations
+from jsonclasses_pymongo.query_to_object import query_to_object
+from jsonclasses_pymongo.query_reader import QueryReader
 from typing import (Iterator, Union, TypeVar, Generator, Optional, Any,
                     Generic, NamedTuple, cast)
+from datetime import date, datetime
 from bson import ObjectId
 from inflection import camelize
 from pymongo.cursor import Cursor
-from jsonclasses.fdef import FieldStorage, FieldType
-from jsonclasses.mark_graph import MarkGraph
-from jsonclasses.exceptions import ObjectNotFoundException
+from jsonclasses.fdef import FStore, FType
+from jsonclasses.mgraph import MGraph
+from jsonclasses.excs import ObjectNotFoundException
 from .coder import Coder
 from .decoder import Decoder
 from .connection import Connection
@@ -41,16 +44,16 @@ class BaseQuery(Generic[T]):
         for subquery in self.subqueries:
             fname = subquery.name
             field = cls.cdef.field_named(fname)
-            if field.fdef.field_type == FieldType.LIST:
+            if field.fdef.ftype == FType.LIST:
                 it = field.fdef.item_types.fdef.inst_cls
             else:
                 it = field.fdef.inst_cls
-            if field.fdef.field_storage == FieldStorage.LOCAL_KEY:
+            if field.fdef.fstore == FStore.LOCAL_KEY:
                 key = ref_db_field_key(fname, cls)
                 if subquery.query is None:
                     result.append({
                         '$lookup': {
-                            'from': it.dbconf.collection_name,
+                            'from': it.pconf.collection_name,
                             'localField': key,
                             'foreignField': '_id',
                             'as': fname
@@ -67,7 +70,7 @@ class BaseQuery(Generic[T]):
                     })
                     result.append({
                         '$lookup': {
-                            'from': it.dbconf.collection_name,
+                            'from': it.pconf.collection_name,
                             'as': fname,
                             'let': {key: '$' + key},
                             'pipeline': subpipeline
@@ -76,13 +79,13 @@ class BaseQuery(Generic[T]):
                 result.append({
                     '$unwind': '$' + fname
                 })
-            elif field.fdef.field_storage == FieldStorage.FOREIGN_KEY:
-                if field.fdef.field_type == FieldType.INSTANCE:
+            elif field.fdef.fstore == FStore.FOREIGN_KEY:
+                if field.fdef.ftype == FType.INSTANCE:
                     fk = cast(str, field.fdef.foreign_key)
                     if subquery.query is None:
                         result.append({
                             '$lookup': {
-                                'from': it.dbconf.collection_name,
+                                'from': it.pconf.collection_name,
                                 'localField': '_id',
                                 'foreignField': ref_db_field_key(fk, it),
                                 'as': fname
@@ -101,7 +104,7 @@ class BaseQuery(Generic[T]):
                         })
                         result.append({
                             '$lookup': {
-                                'from': it.dbconf.collection_name,
+                                'from': it.pconf.collection_name,
                                 'as': fname,
                                 'let': {key: '$_id'},
                                 'pipeline': subp
@@ -110,7 +113,7 @@ class BaseQuery(Generic[T]):
                     result.append({
                         '$unwind': '$' + fname
                     })
-                elif field.fdef.field_type == FieldType.LIST:
+                elif field.fdef.ftype == FType.LIST:
                     if subquery.query is not None:
                         subpipeline = subquery.query \
                                                 ._build_aggregate_pipeline()
@@ -155,7 +158,7 @@ class BaseQuery(Generic[T]):
                             }
                         }}
                         lookup = {'$lookup': {
-                            'from': it.dbconf.collection_name,
+                            'from': it.pconf.collection_name,
                             'as': field.name,
                             'let': {that_key: '$'+that_key},
                             'pipeline': subpipeline
@@ -176,7 +179,7 @@ class BaseQuery(Generic[T]):
                         key = ref_db_field_key(fk, it)
                         item = {
                             '$lookup': {
-                                'from': it.dbconf.collection_name,
+                                'from': it.pconf.collection_name,
                                 'as': fname,
                                 'let': {key: '$_id'},
                                 'pipeline': subpipeline
@@ -203,10 +206,12 @@ class BaseListQuery(BaseQuery[T]):
 
     def __init__(self: V,
                  cls: type[T],
-                 filter: Optional[dict[str, Any]] = None) -> None:
+                 filter: Union[dict[str, Any], str, None] = None) -> None:
         super().__init__(cls)
         self._match: Optional[dict[str, Any]] = None
         self._sort: Optional[list[tuple[str, int]]] = None
+        self._page_number: Optional[int] = None
+        self._page_size: Optional[int] = None
         self._skip: Optional[int] = None
         self._limit: Optional[int] = None
         self._use_pick: bool = False
@@ -214,28 +219,24 @@ class BaseListQuery(BaseQuery[T]):
         self._use_omit: bool = False
         self._omit: Optional[dict[str, Any]] = None
         if filter is not None:
-            self._set_matcher(filter)
+            if type(filter) is str:
+                filter = query_to_object(filter)
+            self._set_matcher(cast(dict, filter))
 
     def _set_matcher(self: V, matcher: dict[str, Any]) -> None:
-        cls = cast(PymongoObject, self._cls)
-        if cls.cdef.primary_field is not None:
-            pf_name: Optional[str] = cls.cdef.primary_field.name
-        else:
-            pf_name = None
-        cls.cdef._camelized_reference_names
-        result: dict[str, Any] = {}
-        for key, value in matcher.items():
-            if key == pf_name:
-                new_value = ObjectId(value) if value is not None else None
-            elif key in cls.cdef._camelized_reference_names:
-                new_value = ObjectId(value) if value is not None else None
-            elif key in cls.cdef._reference_names:
-                new_value = ObjectId(value) if value is not None else None
-            else:
-                new_value = value
-            if cls.dbconf.camelize_db_keys:
-                result[camelize(key, False)] = new_value
-        self._match = result
+        result = QueryReader(query=matcher, cls=self._cls).result()
+        if result.get('_match') is not None:
+            self._match = result['_match']
+        if result.get('_sort') is not None:
+            self._sort = result['_sort']
+        if result.get('_page_number') is not None:
+            self._page_number = result['_page_number']
+        if result.get('_page_size') is not None:
+            self._page_size = result['_page_size']
+        if result.get('_skip') is not None:
+            self._skip = result['_skip']
+        if result.get('_limit') is not None:
+            self._limit = result['_limit']
 
     def order(self: V, field: str, sort: Optional[int] = None) -> V:
         if self._sort is None:
@@ -251,6 +252,19 @@ class BaseListQuery(BaseQuery[T]):
         self._limit = n
         return self
 
+    def page_number(self: V, n: int) -> V:
+        self._page_number = n
+        if self._page_size is None:
+            self._page_size = 30
+        return self
+
+    def page_no(self: V, n: int) -> V:
+        return self.page_number(n)
+
+    def page_size(self: V, n: int) -> V:
+        self._page_size = n
+        return self
+
     def _build_aggregate_pipeline(self: V) -> list[dict[str, Any]]:
         lookups = super()._build_aggregate_pipeline()
         result: list[dict[str, Any]] = []
@@ -258,10 +272,13 @@ class BaseListQuery(BaseQuery[T]):
             result.append({'$match': self._match})
         if self._sort is not None:
             result.append({'$sort': dict(self._sort)})
-        if self._skip is not None:
-            result.append({'$skip': self._skip})
-        if self._limit is not None:
-            result.append({'$limit': self._limit})
+        if self._page_number is not None and self._page_size is not None:
+            result.append({'$skip': (self._page_number - 1) * self._page_size})
+        else:
+            if self._skip is not None:
+                result.append({'$skip': self._skip})
+            if self._limit is not None:
+                result.append({'$limit': self._limit})
         result.extend(lookups)
         return result
 
@@ -408,7 +425,7 @@ class QueryIterator(Generic[T]):
     def __init__(self, cls: type[T], cursor: Cursor):
         self.cls = cls
         self.cursor = cursor
-        self.graph = MarkGraph()
+        self.graph = MGraph()
 
     def __iter__(self):
         return self
@@ -429,13 +446,3 @@ class IterateQuery(BaseListQuery[T]):
     def __await__(self) -> Generator[None, None, Iterator[T]]:
         yield
         return self.exec()
-
-
-# class CountQuery(BaseListQuery[T]):
-
-#     def exec(self) -> int:
-#         pass
-
-#     def __await__(self) -> Generator[None, None, int]:
-#         yield
-#         return self.exec()
