@@ -26,7 +26,7 @@ class TestEncoder(TestCase):
         insert_command = cast(InsertOneCommand, batch_command.commands[0])
         serialized = insert_command.object
         self.assertEqual(set(serialized.keys()), set(
-            ['_id', 'createdAt', 'updatedAt', 'val1', 'val2', 'deletedAt']))
+            ['_id', 'createdAt', 'updatedAt', 'val1', 'val2']))
         self.assertIsInstance(serialized['_id'], ObjectId)
         self.assertEqual(serialized['val1'], 'q')
         self.assertEqual(serialized['val2'], 'e')
@@ -42,7 +42,7 @@ class TestEncoder(TestCase):
         insert_command = cast(InsertOneCommand, batch_command.commands[0])
         serialized = insert_command.object
         self.assertEqual(set(serialized.keys()), set(
-            ['_id', 'createdAt', 'updatedAt', 'age', 'length', 'deletedAt']))
+            ['_id', 'createdAt', 'updatedAt', 'age', 'length']))
         self.assertIsInstance(serialized['_id'], ObjectId)
         self.assertEqual(serialized['age'], 4)
         self.assertEqual(serialized['length'], 8)
@@ -58,7 +58,7 @@ class TestEncoder(TestCase):
         insert_command = cast(InsertOneCommand, batch_command.commands[0])
         serialized = insert_command.object
         self.assertEqual(set(serialized.keys()), set(
-            ['_id', 'createdAt', 'updatedAt', 'width', 'length', 'deletedAt']))
+            ['_id', 'createdAt', 'updatedAt', 'width', 'length']))
         self.assertIsInstance(serialized['_id'], ObjectId)
         self.assertEqual(serialized['width'], 4.5)
         self.assertEqual(serialized['length'], 8.5)
@@ -74,7 +74,7 @@ class TestEncoder(TestCase):
         insert_command = cast(InsertOneCommand, batch_command.commands[0])
         serialized = insert_command.object
         self.assertEqual(set(serialized.keys()), set(
-            ['_id', 'createdAt', 'updatedAt', 'b1', 'b2', 'deletedAt']))
+            ['_id', 'createdAt', 'updatedAt', 'b1', 'b2']))
         self.assertIsInstance(serialized['_id'], ObjectId)
         self.assertEqual(serialized['b1'], True)
         self.assertEqual(serialized['b2'], False)
@@ -90,7 +90,7 @@ class TestEncoder(TestCase):
         insert_command = cast(InsertOneCommand, batch_command.commands[0])
         serialized = insert_command.object
         self.assertEqual(set(serialized.keys()), set(
-            ['_id', 'createdAt', 'updatedAt', 'd1', 'd2', 'deletedAt']))
+            ['_id', 'createdAt', 'updatedAt', 'd1', 'd2']))
         self.assertIsInstance(serialized['_id'], ObjectId)
         self.assertEqual(serialized['d1'], datetime(2012, 9, 15, 0, 0, 0))
         self.assertEqual(serialized['d2'], datetime(2020, 9, 14, 0, 0, 0))
@@ -106,7 +106,7 @@ class TestEncoder(TestCase):
         insert_command = cast(InsertOneCommand, batch_command.commands[0])
         serialized = insert_command.object
         self.assertEqual(set(serialized.keys()), set(
-            ['_id', 'createdAt', 'updatedAt', 'd1', 'd2', 'deletedAt']))
+            ['_id', 'createdAt', 'updatedAt', 'd1', 'd2']))
         self.assertIsInstance(serialized['_id'], ObjectId)
         self.assertEqual(serialized['d1'], datetime(2012, 9, 15, 0, 0, 0))
         self.assertEqual(serialized['d2'], datetime(2020, 9, 14, 0, 0, 0))
@@ -126,7 +126,7 @@ class TestEncoder(TestCase):
         serialized = insert_command.object
         self.assertEqual(set(serialized.keys()), set(
             ['_id', 'createdAt', 'updatedAt', 'strValues', 'intValues',
-             'boolValues', 'deletedAt']))
+             'boolValues']))
         self.assertIsInstance(serialized['_id'], ObjectId)
         self.assertEqual(serialized['strValues'], ['0', '1'])
         self.assertEqual(serialized['intValues'], [0, 1])
@@ -143,7 +143,7 @@ class TestEncoder(TestCase):
         insert_command = cast(InsertOneCommand, batch_command.commands[0])
         serialized = insert_command.object
         self.assertEqual(set(serialized.keys()), set(
-            ['_id', 'createdAt', 'updatedAt', 'strValues', 'deletedAt']))
+            ['_id', 'createdAt', 'updatedAt', 'strValues']))
         self.assertIsInstance(serialized['_id'], ObjectId)
         self.assertEqual(serialized['strValues'], {'0': 'zero', '1': 'one'})
 
@@ -161,7 +161,7 @@ class TestEncoder(TestCase):
         insert_command = cast(InsertOneCommand, batch_command.commands[0])
         serialized = insert_command.object
         self.assertEqual(set(serialized.keys()), set(
-            ['_id', 'createdAt', 'updatedAt', 'vals', 'deletedAt']))
+            ['_id', 'createdAt', 'updatedAt', 'vals']))
         self.assertIsInstance(serialized['_id'], ObjectId)
         self.assertEqual(serialized['vals'], {'0': 'zero', '1': 1})
 
@@ -303,32 +303,19 @@ class TestEncoder(TestCase):
         self.assertEqual(owner_data['addressesIds'], [
                          address_0_data['_id'], address_1_data['_id']])
 
-    def test_encode_dict_camelize_keys(self):
+    def test_encode_dict_keep_keys(self):
         @pymongo
         @jsonclass
         class MediumEncodeCamelizeDictKeys(BaseObject):
             val: Dict[str, str] = types.dictof(types.str)
         simple_object = MediumEncodeCamelizeDictKeys(
-            val={'key_one': 'val_one', 'key_two': 'val_two'})
+            val={'keyOne': 'val_one', 'keyTwo': 'val_two'})
         batch_command = Encoder().encode_root(simple_object)
         commands = batch_command.commands
         encoded_val = commands[0].object['val']
         self.assertEqual(
             encoded_val, {'keyOne': 'val_one', 'keyTwo': 'val_two'})
 
-    def test_encode_dict_do_not_camelize_keys(self):
-        @pymongo(camelize_db_keys=False)
-        @jsonclass
-        class MediumEncodeDoNotCamelizeDictKeys(BaseObject):
-            val: Dict[str, str] = types.dictof(types.str)
-        simple_object = MediumEncodeDoNotCamelizeDictKeys(
-            val={'key_one': 'val_one', 'key_two': 'val_two'})
-        batch_command = Encoder().encode_root(simple_object)
-        commands = batch_command.commands
-        encoded_val = commands[0].object['val']
-        self.assertEqual(
-            encoded_val, {'key_one': 'val_one', 'key_two': 'val_two'})
-
     def test_encode_shape_camelize_keys(self):
         @pymongo
         @jsonclass
